---
title: <span class="badge object-type-scalar"></span> WattPerSquareMeter
---
# <span class="badge object-type-scalar"></span> WattPerSquareMeter

Energy: Watt per square meter (W/m²)

## Definition

```python
# Energy: Watt per square meter (W/m²)
WattPerSquareMeter: typing.Literal["Wm2"] = "Wm2"
```
